feijoa.importance package
=========================

Submodules
----------

feijoa.importance.evaluator module
----------------------------------

.. automodule:: feijoa.importance.evaluator
   :members:
   :undoc-members:
   :show-inheritance:

feijoa.importance.functional\_anova module
------------------------------------------

.. automodule:: feijoa.importance.functional_anova
   :members:
   :undoc-members:
   :show-inheritance:

feijoa.importance.mdi module
----------------------------

.. automodule:: feijoa.importance.mdi
   :members:
   :undoc-members:
   :show-inheritance:

feijoa.importance.pca module
----------------------------

.. automodule:: feijoa.importance.pca
   :members:
   :undoc-members:
   :show-inheritance:

feijoa.importance.rsfanova\_boosted module
------------------------------------------

.. automodule:: feijoa.importance.rsfanova_boosted
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: feijoa.importance
   :members:
   :undoc-members:
   :show-inheritance:
